@@ -1,36 +1,37 @@
 package Net::Appliance::Session::Transport;
 {
-  $Net::Appliance::Session::Transport::VERSION = '3.121640';
+  $Net::Appliance::Session::Transport::VERSION = '4.131260';
 }
 
 {
     package # hide from pause
         Net::Appliance::Session::Transport::ConnectOptions;
-    use Moose;
+    use Moo;
+    use MooX::Types::MooseLike::Base qw(Str);
 
     has username => (
         is => 'ro',
-        isa => 'Str',
+        isa => Str,
         required => 0,
-        predicate => 'has_username',
+        predicate => 1,
     );
 
     has password => (
         is => 'ro',
-        isa => 'Str',
+        isa => Str,
         required => 0,
-        predicate => 'has_password',
+        predicate => 1,
     );
 
     has privileged_password => (
         is => 'ro',
-        isa => 'Str',
+        isa => Str,
         required => 0,
-        predicate => 'has_privileged_password',
+        predicate => 1,
     );
 }
 
-use Moose::Role;
+use Moo::Role;
 
 sub connect {
     my $self = shift;
@@ -49,15 +50,16 @@ sub connect {
     # SSH transport takes a username if we have one
     $self->nci->transport->connect_options->username($self->get_username)
         if $self->has_username
-           and $self->nci->transport->connect_options->meta->find_attribute_by_name('username');
+           and $self->nci->transport->connect_options->can('username');
 
     # poke remote device (whether logging in or not)
     $self->find_prompt($self->wake_up);
 
     # optionally, log in to the remote host
-    if ($self->do_login and not $self->prompt_looks_like('prompt')) {
+    if ($self->do_login and not $self->prompt_looks_like('generic')) {
 
-        if ($self->prompt_looks_like('user')) {
+        if ($self->nci->phrasebook->has_prompt('user')
+            and $self->prompt_looks_like('user')) {
             die 'a set username is required to connect to this host'
                 if not $self->has_username;
 
@@ -67,10 +69,13 @@ sub connect {
         die 'a set password is required to connect to this host'
             if not $self->has_password;
 
-        $self->cmd($self->get_password, { match => 'prompt' });
+        # support for serial console servers where, after loggin in to the
+        # server, the console is asleep and needs waking up to show its prompt
+        $self->say($self->get_password);
+        $self->find_prompt($self->wake_up);
     }
 
-    $self->prompt_looks_like('prompt')
+    $self->prompt_looks_like('generic')
         or die 'login failed to remote host - prompt does not match';
 
     $self->close_called(0);
